@@ -2,10 +2,8 @@
 
 pub mod common;
 pub mod cstr;
+#[cfg(esp_idf_comp_esp_netif_enabled)]
 pub mod net;
 pub mod waitable;
 
 mod stubs;
-
-#[cfg(any(feature = "std"))]
-mod edge_config;
